@@ -5,7 +5,7 @@ package Chart::GGPlot::Backend::Plotly;
 use Chart::GGPlot::Class qw(:pdl);
 use namespace::autoclean;
 
-our $VERSION = '0.0004_01'; # TRIAL VERSION
+our $VERSION = '0.0004_02'; # TRIAL VERSION
 
 with qw(Chart::GGPlot::Backend);
 
@@ -152,8 +152,12 @@ method layer_to_traces ($layer, $data, $prestats_data, $layout, $plot) {
                         } @split_legend
                     );
                     $trace->name($legend_key);
-                    $trace->legendgroup($legend_key);
-                    $trace->showlegend($showlegend);
+
+                    # some types like heatmap may not have below methods
+                    if ( $trace->can('showlegend') ) {
+                        $trace->legendgroup($legend_key);
+                        $trace->showlegend($showlegend);
+                    }
                 }
                 return @$traces;
             }
@@ -405,7 +409,15 @@ method _to_plotly ($plot_built) {
     } # for (qw(x y))
 
     # guides
-    my $gdefs = $plot->guides->build( $plot->scales, labels => $plot->labels );
+    my $gdefs = $plot->guides->build(
+        $plot->scales,
+        labels          => $plot->labels,
+        layers          => $layers,
+        default_mapping => $plot->mapping
+    );
+
+    # if $gdefs is empty, then no legend is displayed.
+    my $global_showlegend = !!@$gdefs;
 
     my %seen_legendgroup;
     for my $i ( 0 .. $#$layers ) {
@@ -421,29 +433,40 @@ method _to_plotly ($plot_built) {
 
         for my $panel (@$traces) {
             for my $trace (@$panel) {
-                $plotly->add_trace($trace);
+                if ( $trace->can('showlegend') ) {
+                    if ( not $global_showlegend ) {
+                        $trace->showlegend(0);
+                    }
+                    elsif ( $seen_legendgroup{ $trace->legendgroup }++ ) {
 
-                # for traces of same legend group, show legend for only the
-                #  first one of them.
-                if ($seen_legendgroup{ $trace->legendgroup }++) {
-                    $trace->showlegend(0);
+                        # for traces of same legend group, show legend for
+                        # only the first one of them.
+                        $trace->showlegend(0);
+                    }
                 }
+
+                $plotly->add_trace($trace);
             }
 
-            if ( List::AllUtils::any { $_->showlegend } @$panel ) {
+            if ( List::AllUtils::any { $_->$_call_if_can('showlegend') }
+                @$panel )
+            {
                 $plotly_layout{showlegend} = JSON::true;
 
                 # legend title
                 #
                 # TODO: See if plotly will officially support legend title
                 #  https://github.com/plotly/plotly.js/issues/276
-                my $legend_titles = join( "\n", map { $_->title } @$gdefs);
+                my $br = br();
+                my $legend_titles =
+                  join( $br, map { $_->title =~ s/\n/$br/gr; } @$gdefs );
 
                 my $annotations = $plotly_layout{annotations} //= [];
                 push @$annotations,
                   {
                     x         => 1.02,
                     y         => 1,
+                    align     => 'left',
                     xanchor   => 'left',
                     yanchor   => 'bottom',
                     text      => $legend_titles,
@@ -562,7 +585,7 @@ Chart::GGPlot::Backend::Plotly - Plotly backend for Chart::GGPlot
 
 =head1 VERSION
 
-version 0.0004_01
+version 0.0004_02
 
 =head1 DESCRIPTION
 
