@@ -8,7 +8,7 @@ use MooseX::Singleton;
 
 extends qw(Chart::GGPlot::Geom::Rect);
 
-our $VERSION = '0.0004_01'; # TRIAL VERSION
+our $VERSION = '0.0004_02'; # TRIAL VERSION
 
 use Chart::GGPlot::Aes;
 use Chart::GGPlot::Layer;
@@ -24,7 +24,7 @@ my $geom_bar_pod = layer_func_pod(<<'EOT');
 
         geom_bar(:$mapping=undef, :$data=undef, :$stat='count',
                  :$position='stack', :$width=undef,
-                 :$na_rm=false, :$show_legend='auto', :$inherit_aes=true,
+                 :$na_rm=false, :$show_legend=undef, :$inherit_aes=true,
                  %rest)
 
     The "bar" geom makes the height bar proportional to the number of cases
@@ -53,7 +53,7 @@ my $geom_bar_code = fun (
         :$mapping = undef, :$data = undef,
         :$stat = 'count', :$position = 'stack',
         :$width = undef, :$na_rm = false,
-        :$show_legend = 'auto', :$inherit_aes = true,
+        :$show_legend = undef, :$inherit_aes = true,
         %rest )
 {
     return Chart::GGPlot::Layer->new(
@@ -76,7 +76,7 @@ my $geom_histogram_pod = layer_func_pod(<<'EOT');
 
         geom_histogram(:$mapping=undef, :$data=undef, :$stat="bin",
                        :$position="stack", :$binwidth=undef, :$bins=undef,
-                       :$na_rm=false, :$show_legend='auto', :$inherit_aes=true,
+                       :$na_rm=false, :$show_legend=undef, :$inherit_aes=true,
                        %rest)
 
     Visualise the distribution of a single continuous variable by dividing
@@ -112,7 +112,7 @@ my $geom_histogram_code = fun (
         :$stat = "bin", :$position = "stack",
         :$binwidth = undef, :$bins = undef,
         :$na_rm = false,
-        :$show_legend = 'auto', :$inherit_aes = true,
+        :$show_legend = undef, :$inherit_aes = true,
         %rest )
 {
     return Chart::GGPlot::Layer->new(
@@ -179,7 +179,7 @@ Chart::GGPlot::Geom::Bar - Class for bar geom
 
 =head1 VERSION
 
-version 0.0004_01
+version 0.0004_02
 
 =head1 SEE ALSO
 
