@@ -4,7 +4,7 @@ package Chart::GGPlot::Geom::Functions;
 
 use Chart::GGPlot::Setup;
 
-our $VERSION = '0.0004_01'; # TRIAL VERSION
+our $VERSION = '0.0004_02'; # TRIAL VERSION
 
 use Chart::GGPlot::Util qw(collect_functions_from_package);
 
@@ -17,6 +17,7 @@ our @sub_namespaces = qw(
   Bar Boxplot
   Path Point Line
   Polygon
+  Rect Tile Raster
   Smooth
 );
 
@@ -50,7 +51,7 @@ Chart::GGPlot::Geom::Functions - Function interface for Chart::GGPlot::Geom
 
 =head1 VERSION
 
-version 0.0004_01
+version 0.0004_02
 
 =head1 DESCRIPTION
 
@@ -67,7 +68,7 @@ L<Chart::GGPlot::Plot> methods, to add layers into the plot object.
 
     geom_bar(:$mapping=undef, :$data=undef, :$stat='count',
              :$position='stack', :$width=undef,
-             :$na_rm=false, :$show_legend='auto', :$inherit_aes=true,
+             :$na_rm=false, :$show_legend=undef, :$inherit_aes=true,
              %rest)
 
 The "bar" geom makes the height bar proportional to the number of cases
@@ -111,8 +112,9 @@ If true, missing values are silently removed.
 =item * $show_legend
 
 Should this layer be included in the legends?
-'auto', the default, includes if any aesthetics are mapped.
-false never includes, and false always includes.
+C<undef>, the default, includes if any aesthetics are mapped.
+A true scalar for never includes, and a defined false scalar for always
+includes.
 
 =item * $inherit_aes
 
@@ -140,7 +142,7 @@ See also L<Chart::GGPlot::Stat::Functions/stat_count>.
 
     geom_histogram(:$mapping=undef, :$data=undef, :$stat="bin",
                    :$position="stack", :$binwidth=undef, :$bins=undef,
-                   :$na_rm=false, :$show_legend='auto', :$inherit_aes=true,
+                   :$na_rm=false, :$show_legend=undef, :$inherit_aes=true,
                    %rest)
 
 Visualise the distribution of a single continuous variable by dividing
@@ -180,8 +182,9 @@ If true, missing values are silently removed.
 =item * $show_legend
 
 Should this layer be included in the legends?
-'auto', the default, includes if any aesthetics are mapped.
-false never includes, and false always includes.
+C<undef>, the default, includes if any aesthetics are mapped.
+A true scalar for never includes, and a defined false scalar for always
+includes.
 
 =item * $inherit_aes
 
@@ -225,7 +228,7 @@ See also L<Chart::GGPlot::Stat::Functions/stat_bin>.
                  :$outlier_alpha=undef,
                  :$notch=false, :$notchwidth=0.25,
                  :$varwidth=false, :$na_rm=false,
-                 :$show_legend='auto', :$inherit_aes=true,
+                 :$show_legend=undef, :$inherit_aes=true,
                  %rest)
 
 The boxplot compactly displays the distribution of a continuous
@@ -267,8 +270,9 @@ If true, missing values are silently removed.
 =item * $show_legend
 
 Should this layer be included in the legends?
-'auto', the default, includes if any aesthetics are mapped.
-false never includes, and false always includes.
+C<undef>, the default, includes if any aesthetics are mapped.
+A true scalar for never includes, and a defined false scalar for always
+includes.
 
 =item * $inherit_aes
 
@@ -315,7 +319,7 @@ See also L<Chart::GGPlot::Stat::Functions/stat_boxplot>.
 =head2 geom_path
 
     geom_path(:$mapping=undef, :$data=undef, :$stat='identity',
-              :$position='identity', :$na_rm=false, :$show_legend='auto',
+              :$position='identity', :$na_rm=false, :$show_legend=undef,
               :$inherit_aes=true, 
               %rest)
 
@@ -355,8 +359,9 @@ If true, missing values are silently removed.
 =item * $show_legend
 
 Should this layer be included in the legends?
-'auto', the default, includes if any aesthetics are mapped.
-false never includes, and false always includes.
+C<undef>, the default, includes if any aesthetics are mapped.
+A true scalar for never includes, and a defined false scalar for always
+includes.
 
 =item * $inherit_aes
 
@@ -378,7 +383,7 @@ They may also be parameters to the paired geom/stat.
 
     geom_point(:$mapping=undef, :$data=undef, :$stat='identity',
                :$position='identity',
-               :$na_rm=false, :$show_legend='auto', :$inherit_aes=true,
+               :$na_rm=false, :$show_legend=undef, :$inherit_aes=true,
                %rest)
 
 The "point" geom is used to create scatterplots.
@@ -422,8 +427,9 @@ If true, missing values are silently removed.
 =item * $show_legend
 
 Should this layer be included in the legends?
-'auto', the default, includes if any aesthetics are mapped.
-false never includes, and false always includes.
+C<undef>, the default, includes if any aesthetics are mapped.
+A true scalar for never includes, and a defined false scalar for always
+includes.
 
 =item * $inherit_aes
 
@@ -444,7 +450,7 @@ They may also be parameters to the paired geom/stat.
 =head2 geom_line
 
     geom_line(:$mapping=undef, :$data=undef, :$stat='identity',
-              :$position='identity', :$na_rm=false, :$show_legend='auto',
+              :$position='identity', :$na_rm=false, :$show_legend=undef,
               :$inherit_aes=true, 
               %rest)
 
@@ -486,8 +492,9 @@ If true, missing values are silently removed.
 =item * $show_legend
 
 Should this layer be included in the legends?
-'auto', the default, includes if any aesthetics are mapped.
-false never includes, and false always includes.
+C<undef>, the default, includes if any aesthetics are mapped.
+A true scalar for never includes, and a defined false scalar for always
+includes.
 
 =item * $inherit_aes
 
@@ -509,7 +516,7 @@ They may also be parameters to the paired geom/stat.
 
     geom_polygon(:$mapping=undef, :$data=undef,
                  :$stat='identity', :$position='identity',
-                 :$na_rm=false, :$show_legend='auto',
+                 :$na_rm=false, :$show_legend=undef,
                  :$inherit_aes=true,
                  %rest)
 
@@ -551,8 +558,205 @@ If true, missing values are silently removed.
 =item * $show_legend
 
 Should this layer be included in the legends?
-'auto', the default, includes if any aesthetics are mapped.
-false never includes, and false always includes.
+C<undef>, the default, includes if any aesthetics are mapped.
+A true scalar for never includes, and a defined false scalar for always
+includes.
+
+=item * $inherit_aes
+
+If false, overrides the default aesthetics, rather than combining with them.
+This is most useful for helper functions that define both data and
+aesthetics and shouldn't inherit behaviour from the default plot
+specification.
+
+=item * %rest
+
+Other arguments passed to C<Chart::GGPlot::Layer-E<gt>new()>.
+These are often aesthetics, used to set an aesthetic to a fixed value,
+like C<color =E<gt> "red", size =E<gt> 3>.
+They may also be parameters to the paired geom/stat.
+
+=back
+
+=head2 geom_rect
+
+    geom_rect(:$mapping=undef, :$data=undef, :$stat='count',
+              :$position='stack', :$width=undef,
+              :$na_rm=false, :$show_legend=undef, :$inherit_aes=true,
+              %rest)
+
+C<geom_rect()> uses the locations of the four corners
+(aethetics C<xmin>, C<xmax>, C<ymin> and C<ymax>) to define rectangles.
+
+Arguments:
+
+=over 4
+
+=item * $mapping
+
+Set of aesthetic mappings created by C<aes()>. If specified and
+C<$inherit_aes> is true (the default), it is combined with the default
+mapping at the top level of the plot.
+You must supply mapping if there is no plot mapping.
+
+=item * $data
+
+The data to be displayed in this layer.
+If C<undef>, the default, the data is inherited from the plot data as
+specified in the call to C<ggplot()>.
+
+=item * $stat
+
+The statistical transformation to use on the data for this layer, as a
+string.
+
+=item * $position
+
+Position adjustment, either as a string, or the result of a call to a
+position adjustment function.
+
+=item * $na_rm
+
+If false, the default, missing values are removed with a warning.
+If true, missing values are silently removed.
+
+=item * $show_legend
+
+Should this layer be included in the legends?
+C<undef>, the default, includes if any aesthetics are mapped.
+A true scalar for never includes, and a defined false scalar for always
+includes.
+
+=item * $inherit_aes
+
+If false, overrides the default aesthetics, rather than combining with them.
+This is most useful for helper functions that define both data and
+aesthetics and shouldn't inherit behaviour from the default plot
+specification.
+
+=item * %rest
+
+Other arguments passed to C<Chart::GGPlot::Layer-E<gt>new()>.
+These are often aesthetics, used to set an aesthetic to a fixed value,
+like C<color =E<gt> "red", size =E<gt> 3>.
+They may also be parameters to the paired geom/stat.
+
+=back
+
+=head2 geom_tile
+
+    geom_tile(:$mapping=undef, :$data=undef, :$stat='count',
+              :$position='stack', :$width=undef,
+              :$na_rm=false, :$show_legend=undef, :$inherit_aes=true,
+              %rest)
+
+C<geom_tile()> uses the center of the tile and its size
+(aesthetics C<x>, C<y>, C<width> and C<height>) to define rectangles.
+
+Arguments:
+
+=over 4
+
+=item * $mapping
+
+Set of aesthetic mappings created by C<aes()>. If specified and
+C<$inherit_aes> is true (the default), it is combined with the default
+mapping at the top level of the plot.
+You must supply mapping if there is no plot mapping.
+
+=item * $data
+
+The data to be displayed in this layer.
+If C<undef>, the default, the data is inherited from the plot data as
+specified in the call to C<ggplot()>.
+
+=item * $stat
+
+The statistical transformation to use on the data for this layer, as a
+string.
+
+=item * $position
+
+Position adjustment, either as a string, or the result of a call to a
+position adjustment function.
+
+=item * $na_rm
+
+If false, the default, missing values are removed with a warning.
+If true, missing values are silently removed.
+
+=item * $show_legend
+
+Should this layer be included in the legends?
+C<undef>, the default, includes if any aesthetics are mapped.
+A true scalar for never includes, and a defined false scalar for always
+includes.
+
+=item * $inherit_aes
+
+If false, overrides the default aesthetics, rather than combining with them.
+This is most useful for helper functions that define both data and
+aesthetics and shouldn't inherit behaviour from the default plot
+specification.
+
+=item * %rest
+
+Other arguments passed to C<Chart::GGPlot::Layer-E<gt>new()>.
+These are often aesthetics, used to set an aesthetic to a fixed value,
+like C<color =E<gt> "red", size =E<gt> 3>.
+They may also be parameters to the paired geom/stat.
+
+=back
+
+=head2 geom_raster
+
+    geom_raster(:$mapping=undef, :$data=undef, :$stat='count',
+                Num :$hjust=0.5, Num :$vjust=0.5,
+                :$position='stack', :$width=undef,
+                :$na_rm=false, :$show_legend=undef, :$inherit_aes=true,
+                %rest)
+
+C<geom_raster()> is a high performance special case of C<geom_tile()>
+for when all the tiles are the same size.
+
+Arguments:
+
+=over 4
+
+=item * $mapping
+
+Set of aesthetic mappings created by C<aes()>. If specified and
+C<$inherit_aes> is true (the default), it is combined with the default
+mapping at the top level of the plot.
+You must supply mapping if there is no plot mapping.
+
+=item * $data
+
+The data to be displayed in this layer.
+If C<undef>, the default, the data is inherited from the plot data as
+specified in the call to C<ggplot()>.
+
+=item * $stat
+
+The statistical transformation to use on the data for this layer, as a
+string.
+
+=item * $position
+
+Position adjustment, either as a string, or the result of a call to a
+position adjustment function.
+
+=item * $na_rm
+
+If false, the default, missing values are removed with a warning.
+If true, missing values are silently removed.
+
+=item * $show_legend
+
+Should this layer be included in the legends?
+C<undef>, the default, includes if any aesthetics are mapped.
+A true scalar for never includes, and a defined false scalar for always
+includes.
 
 =item * $inherit_aes
 
@@ -572,10 +776,11 @@ They may also be parameters to the paired geom/stat.
 
 =head2 geom_smooth
 
-    geom_smooth(:$mapping=undef, :$data=undef, :$stat='count',
-             :$position='stack', :$width=undef,
-             :$na_rm=false, :$show_legend='auto', :$inherit_aes=true,
-             %rest)
+    geom_smooth(:$mapping=undef, :$data=undef,
+                :$stat='smooth', :$position='identity',
+                :$method='auto', :$se=true,
+                :$na_rm=false, :$show_legend=undef, :$inherit_aes=true,
+                %rest)
 
 Aids the eye in seeing patterns in the presence of overplotting, by
 calculating a smoothed conditional mean.
@@ -619,8 +824,9 @@ If true, missing values are silently removed.
 =item * $show_legend
 
 Should this layer be included in the legends?
-'auto', the default, includes if any aesthetics are mapped.
-false never includes, and false always includes.
+C<undef>, the default, includes if any aesthetics are mapped.
+A true scalar for never includes, and a defined false scalar for always
+includes.
 
 =item * $inherit_aes
 
