@@ -6,7 +6,7 @@ use Chart::GGPlot::Class qw(:pdl);
 use namespace::autoclean;
 use MooseX::Singleton;
 
-our $VERSION = '0.0004_01'; # TRIAL VERSION
+our $VERSION = '0.0004_02'; # TRIAL VERSION
 
 use List::AllUtils qw(reduce);
 use PDL::Primitive qw(which);
@@ -35,7 +35,7 @@ classmethod required_aes () { [qw(x y)] }
 my $geom_path_pod = layer_func_pod(<<'EOT');
 
         geom_path(:$mapping=undef, :$data=undef, :$stat='identity',
-                  :$position='identity', :$na_rm=false, :$show_legend='auto',
+                  :$position='identity', :$na_rm=false, :$show_legend=undef,
                   :$inherit_aes=true, 
                   %rest)
 
@@ -54,7 +54,7 @@ my $geom_path_code = fun (
         :$mapping = undef, :$data = undef,
         :$stat = 'identity', :$position = 'identity',
         :$na_rm = false,
-        :$show_legend = 'auto', :$inherit_aes = true,
+        :$show_legend = undef, :$inherit_aes = true,
         %rest )
 {
     return Chart::GGPlot::Layer->new(
@@ -155,7 +155,7 @@ Chart::GGPlot::Geom::Path - Class for path geom
 
 =head1 VERSION
 
-version 0.0004_01
+version 0.0004_02
 
 =head1 SEE ALSO
 
