@@ -6,7 +6,7 @@ use Chart::GGPlot::Class qw(:pdl);
 use namespace::autoclean;
 use MooseX::Singleton;
 
-our $VERSION = '0.0004_01'; # TRIAL VERSION
+our $VERSION = '0.0004_02'; # TRIAL VERSION
 
 use Chart::GGPlot::Aes;
 use Chart::GGPlot::Layer;
@@ -35,7 +35,7 @@ my $geom_point_pod = layer_func_pod(<<'EOT');
 
         geom_point(:$mapping=undef, :$data=undef, :$stat='identity',
                    :$position='identity',
-                   :$na_rm=false, :$show_legend='auto', :$inherit_aes=true,
+                   :$na_rm=false, :$show_legend=undef, :$inherit_aes=true,
                    %rest)
 
     The "point" geom is used to create scatterplots.
@@ -58,7 +58,7 @@ my $geom_point_code = fun (
         :$mapping = undef, :$data = undef,
         :$stat = 'identity', :$position = 'identity',
         :$na_rm = false,
-        :$show_legend = 'auto', :$inherit_aes = true,
+        :$show_legend = undef, :$inherit_aes = true,
         %rest )
 {
     return Chart::GGPlot::Layer->new(
@@ -99,7 +99,7 @@ Chart::GGPlot::Geom::Point - Class for point geom
 
 =head1 VERSION
 
-version 0.0004_01
+version 0.0004_02
 
 =head1 SEE ALSO
 
