@@ -8,7 +8,7 @@ use MooseX::Singleton;
 
 extends qw(Chart::GGPlot::Geom::Line);
 
-our $VERSION = '0.0004_01'; # TRIAL VERSION
+our $VERSION = '0.0004_02'; # TRIAL VERSION
 
 use Chart::GGPlot::Aes;
 use Chart::GGPlot::Layer;
@@ -32,10 +32,11 @@ classmethod optional_aes() { [qw(ymin ymax)] }
 
 my $geom_smooth_pod = layer_func_pod(<<'EOT');
 
-        geom_smooth(:$mapping=undef, :$data=undef, :$stat='count',
-                 :$position='stack', :$width=undef,
-                 :$na_rm=false, :$show_legend='auto', :$inherit_aes=true,
-                 %rest)
+        geom_smooth(:$mapping=undef, :$data=undef,
+                    :$stat='smooth', :$position='identity',
+                    :$method='auto', :$se=true,
+                    :$na_rm=false, :$show_legend=undef, :$inherit_aes=true,
+                    %rest)
 
     Aids the eye in seeing patterns in the presence of overplotting, by
     calculating a smoothed conditional mean.
@@ -61,7 +62,7 @@ my $geom_smooth_code = fun (
         :$stat = 'smooth', :$position = 'identity',
         :$method = 'auto',
         :$se = true,
-        :$na_rm = false, :$show_legend = 'auto', :$inherit_aes = true,
+        :$na_rm = false, :$show_legend = undef, :$inherit_aes = true,
         %rest )
 {
     return Chart::GGPlot::Layer->new(
@@ -107,7 +108,7 @@ Chart::GGPlot::Geom::Smooth - Class for smooth geom
 
 =head1 VERSION
 
-version 0.0004_01
+version 0.0004_02
 
 =head1 SEE ALSO
 
