@@ -6,7 +6,7 @@ use Chart::GGPlot::Setup;
 use Function::Parameters qw(classmethod);
 use namespace::autoclean;
 
-our $VERSION = '0.0004_01'; # TRIAL VERSION
+our $VERSION = '0.0004_02'; # TRIAL VERSION
 
 use parent qw(Chart::GGPlot::Params);
 
@@ -21,12 +21,17 @@ for my $attr (qw(title key reverse)) {
     *{$attr} = sub { $_[0]->at($attr); }
 }
 
+# undef means "any"
 classmethod available_aes () { undef; }
 
 method train ($scale, $aesthetics=undef) {
     return $self;
 }
 
+classmethod _reverse_df ($df) {
+    return $df->select_rows( [ reverse( 0 .. $df->nrow - 1 ) ] );
+}
+
 1;
 
 __END__
@@ -41,7 +46,7 @@ Chart::GGPlot::Guide - Role for guide
 
 =head1 VERSION
 
-version 0.0004_01
+version 0.0004_02
 
 =head1 ATTRIBUTES
 
