@@ -4,7 +4,7 @@ package Chart::GGPlot::Stat::Functions;
 
 use Chart::GGPlot::Setup;
 
-our $VERSION = '0.0004_01'; # TRIAL VERSION
+our $VERSION = '0.0004_02'; # TRIAL VERSION
 
 use Module::Load;
 
@@ -45,7 +45,7 @@ Chart::GGPlot::Stat::Functions - Function interface for stats
 
 =head1 VERSION
 
-version 0.0004_01
+version 0.0004_02
 
 =head1 DESCRIPTION
 
@@ -96,8 +96,9 @@ If true, missing values are silently removed.
 =item * $show_legend
 
 Should this layer be included in the legends?
-'auto', the default, includes if any aesthetics are mapped.
-false never includes, and false always includes.
+C<undef>, the default, includes if any aesthetics are mapped.
+A true scalar for never includes, and a defined false scalar for always
+includes.
 
 =item * $inherit_aes
 
@@ -172,8 +173,9 @@ If true, missing values are silently removed.
 =item * $show_legend
 
 Should this layer be included in the legends?
-'auto', the default, includes if any aesthetics are mapped.
-false never includes, and false always includes.
+C<undef>, the default, includes if any aesthetics are mapped.
+A true scalar for never includes, and a defined false scalar for always
+includes.
 
 =item * $inherit_aes
 
@@ -238,8 +240,9 @@ If true, missing values are silently removed.
 =item * $show_legend
 
 Should this layer be included in the legends?
-'auto', the default, includes if any aesthetics are mapped.
-false never includes, and false always includes.
+C<undef>, the default, includes if any aesthetics are mapped.
+A true scalar for never includes, and a defined false scalar for always
+includes.
 
 =item * $inherit_aes
 
@@ -303,8 +306,9 @@ If true, missing values are silently removed.
 =item * $show_legend
 
 Should this layer be included in the legends?
-'auto', the default, includes if any aesthetics are mapped.
-false never includes, and false always includes.
+C<undef>, the default, includes if any aesthetics are mapped.
+A true scalar for never includes, and a defined false scalar for always
+includes.
 
 =item * $inherit_aes
 
@@ -324,13 +328,13 @@ They may also be parameters to the paired geom/stat.
 
 =head2 stat_smooth
 
-stat_smooth(:$maping=undef, :$data=undef,
-            :$geom='smooth', :$position='identity',
-            :$method='auto', :$se=true,
-            :$n=80, :$span=0.75, :$fullrange=false, :$level=0.95,
-            :$method_args={},
-            :$na_rm=false, :$show_legend='auto', :$inherit_aes=true,
-            %rest)
+    stat_smooth(:$maping=undef, :$data=undef,
+                :$geom='smooth', :$position='identity',
+                :$method='auto', :$se=true,
+                :$n=80, :$span=0.75, :$fullrange=false, :$level=0.95,
+                :$method_args={},
+                :$na_rm=false, :$show_legend='auto', :$inherit_aes=true,
+                %rest)
 
 Arguments:
 
@@ -367,8 +371,9 @@ If true, missing values are silently removed.
 =item * $show_legend
 
 Should this layer be included in the legends?
-'auto', the default, includes if any aesthetics are mapped.
-false never includes, and false always includes.
+C<undef>, the default, includes if any aesthetics are mapped.
+A true scalar for never includes, and a defined false scalar for always
+includes.
 
 =item * $inherit_aes
 
@@ -402,7 +407,7 @@ Locally Weighted Regression
 
 Requires L<Math::LOESS>.
 
-Supported C<$method_args>, (see L<Math::LOESS::Model> for details, )
+Supported C<$method_args>, (see L<Math::LOESS::Model> for details)
 
 =over 12
 
@@ -422,8 +427,8 @@ Supported C<$method_args>, (see L<Math::LOESS::Model> for details, )
 
 Requires L<PDL::Stats::GLM> and L<PDL::GSL::CDF>.
 
-At this moment we can do only simple linear modeling. To support logistic
-and polynomial in future.
+At this moment we can do only simple linear modeling. Still to support
+logistic and polynomial in future.
 
 Supported C<$method_args>,
 
